@@ -1,14 +1,12 @@
-# -*- coding: utf-8 -*-
-
 """Utilities for interacting with Slack."""
 
 import logging
 from functools import lru_cache
-from typing import Optional
 
 import pystow
 from slack_sdk import WebClient
 from slack_sdk.errors import SlackApiError
+from slack_sdk.web import SlackResponse
 
 __all__ = [
     "post",
@@ -18,14 +16,14 @@ logger = logging.getLogger(__name__)
 
 
 @lru_cache(maxsize=1)
-def _get_client(token: Optional[str] = None) -> Optional[WebClient]:
+def _get_client(token: str | None = None) -> WebClient | None:
     token = pystow.get_config("bioversions", "slack_api_token", passthrough=token)
     if token is None:
         return None
     return WebClient(token=token)
 
 
-def post(text: str, channel: str = "random", token: Optional[str] = None):
+def post(text: str, channel: str = "random", token: str | None = None) -> SlackResponse | None:
     """Post the message to a given Slack channel."""
     client = _get_client(token)
     if client is None:
@@ -43,6 +41,7 @@ def post(text: str, channel: str = "random", token: Optional[str] = None):
         if not e.response["ok"]:
             raise ValueError('Response is not "ok"') from e
         logger.warning(f"Got an error: {e.response['error']}")
+        return None
     else:
         return response
 
