@@ -1,5 +1,8 @@
 """Get the version for CiVIC."""
 
+import datetime
+from typing import ClassVar
+
 import requests
 
 from bioversions.utils import Getter, VersionType
@@ -7,16 +10,13 @@ from bioversions.utils import Getter, VersionType
 URL = "https://civicdb.org/releases/main"
 API = "https://civicdb.org/api/graphql"
 GRAPHQL_QUERY = """\
-query dataReleases {
+query DataReleases {
   dataReleases {
-    geneTsv {
-      filename
-      path
-    }
     name
   }
 }
 """
+
 # see https://griffithlab.github.io/civic-v2/#query-dataReleases
 # and https://griffithlab.github.io/civic-v2/#definition-DownloadableFile
 
@@ -28,13 +28,14 @@ class CiVICGetter(Getter):
     date_fmt = "%d-%b-%Y"
     version_type = VersionType.date
     homepage = "https://civicdb.org"
-    collection = ["civic.gid", "civic.eid"]
+    collection: ClassVar[list[str]] = ["civic.gid", "civic.eid"]
 
-    def get(self):
+    def get(self) -> datetime.datetime:
         """Get the latest ChEMBL version number."""
-        res = requests.post(API, json={"query": GRAPHQL_QUERY})
+        res = requests.post(API, json={"query": GRAPHQL_QUERY}, timeout=15)
         # 0 element is always nightly, 1 is latest
-        return res.json()["data"]["dataReleases"][1]["name"]
+        value = res.json()["data"]["dataReleases"][1]["name"]
+        return datetime.datetime.strptime(value, "%d-%b-%Y")
 
 
 if __name__ == "__main__":
