@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
-
 """A web application for listing database versions."""
 
-from typing import Any, Dict
+from typing import Any
 
 import flask
 from flask_bootstrap import Bootstrap
@@ -14,22 +12,22 @@ Bootstrap(app)
 
 
 @app.route("/")
-def home():
+def home() -> str:
     """Show the home page with a list of latest database versions."""
     return flask.render_template("home.html", rows=get_rows())
 
 
 @app.route("/database/<name>.json")
-def database(name: str):
+def database(name: str) -> flask.Response:
     """Resolve information about a given database."""
-    rv: Dict[str, Any] = dict(query=name)
+    rv: dict[str, Any] = {"query": name}
     try:
         bioversion = resolve(name)
     except KeyError:
         rv["success"] = False
     else:
         rv["success"] = True
-        rv["result"] = bioversion.dict()
+        rv["result"] = bioversion.model_dump()
     return flask.jsonify(rv)
 
 
